==> sugarcrm-5.5.1.tbz: www/sugarcrm/modules/Calls/language/en_us.lang.php <==
<?php
if(!defined('sugarEntry') || !sugarEntry) die('Not A Valid Entry Point');
/*********************************************************************************
 * SugarCRM is a customer relationship management program developed by
 * SugarCRM, Inc. Copyright (C) 2004-2010 SugarCRM Inc.
 * 
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU General Public License version 3 as published by the
 * Free Software Foundation with the addition of the following permission added
 * to Section 15 as permitted in Section 7(a): FOR ANY PART OF THE COVERED WORK
 * IN WHICH THE COPYRIGHT IS OWNED BY SUGARCRM, SUGARCRM DISCLAIMS THE WARRANTY
 * OF NON INFRINGEMENT OF THIRD PARTY RIGHTS.
 * 
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
 * details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * this program; if not, see http://www.gnu.org/licenses or write to the Free
 * Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 * 02110-1301 USA.
 * 
 * You can contact SugarCRM, Inc. headquarters at 10050 North Wolfe Road,
 * SW2-130, Cupertino, CA 95014, USA. or at email address contact@sugarcrm.com.
 * 
 * The interactive user interfaces in modified source and object code versions
 * of this program must display Appropriate Legal Notices, as required under
 * Section 5 of the GNU General Public License version 3.
 * 
 * In accordance with Section 7(b) of the GNU General Public License version 3,
 * these Appropriate Legal Notices must retain the display of the "Powered by
 * SugarCRM" logo. If the display of the logo is not reasonably feasible for
 * technical reasons, the Appropriate Legal Notices must display the words
 * "Powered by SugarCRM".
 ********************************************************************************/
/*********************************************************************************

 * Description:  Defines the English language pack for the base application.
 * Portions created by SugarCRM are Copyright (C) SugarCRM, Inc.
 * All Rights Reserved.
 * Contributor(s): ______________________________________..
 ********************************************************************************/

$mod_strings = array (
	'LBL_BLANK'	=> ' ',

  'LBL_MODULE_NAME' => 'Calls',
  'LBL_MODULE_TITLE' => 'Calls: Home',
  'LBL_SEARCH_FORM_TITLE' => 'Call Search',
  'LBL_LIST_FORM_TITLE' => 'Call List',
  'LBL_NEW_FORM_TITLE' => 'Create Appointment',
  'LBL_LIST_CLOSE' => 'Close',
  'LBL_LIST_SUBJECT' => 'Subject',
  'LBL_LIST_CONTACT' => 'Contact',
  'LBL_LIST_RELATED_TO' => 'Related to',
  'LBL_LIST_RELATED_TO_ID' => 'Related to ID',
  'LBL_LIST_DATE' => 'Start Date',
  'LBL_LIST_TIME' => 'Start Time',
  'LBL_LIST_DURATION' => 'Duration',
  'LBL_LIST_DIRECTION' => 'Direction',
  'LBL_SUBJECT' => 'Subject:',
  'LBL_REMINDER' => 'Reminder:',
  'LBL_CONTACT_NAME' => 'Contact:',
  'LBL_DESCRIPTION_INFORMATION' => 'Description Information',
  'LBL_DESCRIPTION' => 'Description:',
  'LBL_STATUS' => 'Status:',
  'LBL_DIRECTION' => 'Direction:',
  'LBL_DATE' => 'Start Date:',
  'LBL_DURATION' => 'Duration:',
  'LBL_DURATION_HOURS' => 'Duration Hours:',
  'LBL_DURATION_MINUTES' => 'Duration Minutes:',
  'LBL_HOURS_MINUTES' => '(hours/minutes)',
  'LBL_CALL' => 'Call:',
  'LBL_DATE_TIME' => 'Start Date & Time:',
  'LBL_TIME' => 'Start Time:',
  'LBL_HOURS_ABBREV' => 'h',
  'LBL_MINSS_ABBREV' => 'm',
  'LBL_COLON' => ':',
  'LBL_DEFAULT_STATUS' => 'Planned',
  'LNK_NEW_CALL' => 'Schedule Call',
  'LNK_NEW_MEETING' => 'Schedule Meeting',
  'LNK_NEW_TASK' => 'Create Task',
  'LNK_NEW_NOTE' => 'Create Note or Attachment',
  'LNK_NEW_EMAIL' => 'Archive Email',
  'LNK_CALL_LIST' => 'Calls',
  'LNK_MEETING_LIST' => 'Meetings',
  'LNK_TASK_LIST' => 'Tasks',
  'LNK_NOTE_LIST' => 'Notes',
  'LNK_EMAIL_LIST' => 'Emails',
  'LNK_VIEW_CALENDAR' => 'Today',
  'ERR_DELETE_RECORD' => 'A record number must be specified to delete the account.',
  'NTC_REMOVE_INVITEE' => 'Are you sure you want to remove this invitee from the call?',
  'LBL_INVITEE' => 'Invitees',
  'LBL_RELATED_TO' => 'Related To:',
  'LNK_NEW_APPOINTMENT' => 'Create Appointment',
	'LBL_SCHEDULING_FORM_TITLE' => 'Scheduling',
  'LBL_ADD_INVITEE' => 'Add Invitees',
  'LBL_NAME' => 'Name',
  'LBL_FIRST_NAME' => 'First Name',
  'LBL_LAST_NAME' => 'Last Name',
  'LBL_EMAIL' => 'Email',
  'LBL_PHONE' => 'Phone',
  'LBL_REMINDER' => 'Reminder:',
  'LBL_SEND_BUTTON_TITLE'=>'Send Invites [Alt+I]',
  'LBL_SEND_BUTTON_KEY'=>'I',
  'LBL_SEND_BUTTON_LABEL'=>'Send Invites',
	'LBL_DATE_END'=>'Date End',
	'LBL_TIME_END'=>'Time End',
	'LBL_REMINDER_TIME'=>'Reminder Time',
   'LBL_SEARCH_BUTTON'=> 'Search',
  'LBL_ACTIVITIES_REPORTS' => 'Activities Report',    
   'LBL_ADD_BUTTON'=> 'Add',
	'LBL_DEFAULT_SUBPANEL_TITLE' => 'Calls',
   'LBL_LOG_CALL'=> 'Log Call',
   'LNK_SELECT_ACCOUNT'=> 'Select Account',
   'LNK_NEW_ACCOUNT'=> 'New Account',
   'LNK_NEW_OPPORTUNITY'=> 'New Opportunity',
    'LBL_DEL' => 'Del',
    'LBL_LEADS_SUBPANEL_TITLE' => 'Leads',
    'LBL_CONTACTS_SUBPANEL_TITLE' => 'Contacts',
    'LBL_USERS_SUBPANEL_TITLE' => 'Users',
    'LBL_OUTLOOK_ID' => 'Outlook ID',
    'LBL_MEMBER_OF' => 'Member Of',
    'LBL_HISTORY_SUBPANEL_TITLE' => 'Notes',
   'LBL_LIST_ASSIGNED_TO_NAME' => 'Assigned to',
   'LBL_LIST_MY_CALLS' => 'My Calls',
   'LBL_SELECT_FROM_DROPDOWN' => 'Please make a selection from the Related To dropdown list first.',
	'LBL_ASSIGNED_TO_NAME' => 'Assigned to',
	'LBL_ASSIGNED_TO_ID' => 'Assigned User',
    'NOTICE_DURATION_TIME' => 'Duration time must be greater than 0',
   );


?>

==> sugarcrm-6.2.1.tbz: www/sugarcrm/modules/Calls/language/en_us.lang.php <==
<?php
if(!defined('sugarEntry') || !sugarEntry) die('Not A Valid Entry Point');
/*********************************************************************************
 * SugarCRM Community Edition is a customer relationship management program developed by
 * SugarCRM, Inc. Copyright (C) 2004-2011 SugarCRM Inc.
 * 
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Affero General Public License version 3 as published by the
 * Free Software Foundation with the addition of the following permission added
 * to Section 15 as permitted in Section 7(a): FOR ANY PART OF THE COVERED WORK
 * IN WHICH THE COPYRIGHT IS OWNED BY SUGARCRM, SUGARCRM DISCLAIMS THE WARRANTY
 * OF NON INFRINGEMENT OF THIRD PARTY RIGHTS.
 * 
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public License for more
 * details.
 * 
 * You should have received a copy of the GNU Affero General Public License along with
 * this program; if not, see http://www.gnu.org/licenses or write to the Free
 * Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 * 02110-1301 USA.
 * 
 * You can contact SugarCRM, Inc. headquarters at 10050 North Wolfe Road,
 * SW2-130, Cupertino, CA 95014, USA. or at email address contact@sugarcrm.com.
 * 
 * The interactive user interfaces in modified source and object code versions
 * of this program must display Appropriate Legal Notices, as required under
 * Section 5 of the GNU Affero General Public License version 3.
 * 
 * In accordance with Section 7(b) of the GNU Affero General Public License version 3,
 * these Appropriate Legal Notices must retain the display of the "Powered by
 * SugarCRM" logo. If the display of the logo is not reasonably feasible for
 * technical reasons, the Appropriate Legal Notices must display the words
 * "Powered by SugarCRM".
 ********************************************************************************/

/*********************************************************************************

 * Description:  Defines the English language pack for the base application.
 * Portions created by SugarCRM are Copyright (C) SugarCRM, Inc.
 * All Rights Reserved.
 * Contributor(s): ______________________________________..
 ********************************************************************************/

$mod_strings = array (
	'LBL_BLANK'	=> ' ',

  'LBL_MODULE_NAME' => 'Calls',
  'LBL_MODULE_TITLE' => 'Calls: Home',
  'LBL_SEARCH_FORM_TITLE' => 'Call Search',
  'LBL_LIST_FORM_TITLE' => 'Call List',
  'LBL_NEW_FORM_TITLE' => 'Create Appointment',
  'LBL_LIST_CLOSE' => 'Close',
  'LBL_LIST_SUBJECT' => 'Subject',
  'LBL_LIST_CONTACT' => 'Contact',
  'LBL_LIST_RELATED_TO' => 'Related to',
  'LBL_LIST_RELATED_TO_ID' => 'Related to ID',
  'LBL_LIST_DATE' => 'Start Date',
  'LBL_LIST_TIME' => 'Start Time',
  'LBL_LIST_DURATION' => 'Duration',
  'LBL_LIST_DIRECTION' => 'Direction',
  'LBL_SUBJECT' => 'Subject:',
  'LBL_REMINDER' => 'Reminder:',
  'LBL_CONTACT_NAME' => 'Contact:',
  'LBL_DESCRIPTION_INFORMATION' => 'Description Information',
  'LBL_DESCRIPTION' => 'Description:',
  'LBL_STATUS' => 'Status:',
  'LBL_DIRECTION' => 'Direction:',
  'LBL_DATE' => 'Start Date:',
  'LBL_DURATION' => 'Duration:',
  'LBL_DURATION_HOURS' => 'Duration Hours:',
  'LBL_DURATION_MINUTES' => 'Duration Minutes:',
  'LBL_HOURS_MINUTES' => '(hours/minutes)',
  'LBL_CALL' => 'Call:',
  'LBL_DATE_TIME' => 'Start Date & Time:',
  'LBL_TIME' => 'Start Time:',
  'LBL_HOURS_ABBREV' => 'h',
  'LBL_MINSS_ABBREV' => 'm',
  'LBL_COLON' => ':',
  'LNK_NEW_CALL' => 'Log Call',
  'LNK_NEW_MEETING' => 'Schedule Meeting',
  'LNK_CALL_LIST' => 'View Calls',
  'LNK_IMPORT_CALLS' => 'Import Calls',
  'ERR_DELETE_RECORD' => 'A record number must be specified to delete the account.',
  'NTC_REMOVE_INVITEE' => 'Are you sure you want to remove this invitee from the call?',
  'LBL_INVITEE' => 'Invitees',
  'LBL_RELATED_TO' => 'Related To:',
  'LNK_NEW_APPOINTMENT' => 'Create Appointment',
	'LBL_SCHEDULING_FORM_TITLE' => 'Scheduling',
  'LBL_ADD_INVITEE' => 'Add Invitees',
  'LBL_NAME' => 'Name',
  'LBL_FIRST_NAME' => 'First Name',
  'LBL_LAST_NAME' => 'Last Name',
  'LBL_EMAIL' => 'Email',
  'LBL_PHONE' => 'Phone',
  'LBL_REMINDER' => 'Reminder:',
  'LBL_SEND_BUTTON_TITLE'=>'Send Invites [Alt+I]',
  'LBL_SEND_BUTTON_KEY'=>'I',
  'LBL_SEND_BUTTON_LABEL'=>'Send Invites',
	'LBL_DATE_END'=>'Date End',
	'LBL_TIME_END'=>'Time End',
	'LBL_REMINDER_TIME'=>'Reminder Time',
   'LBL_SEARCH_BUTTON'=> 'Search',
  'LBL_ACTIVITIES_REPORTS' => 'Activities Report',
   'LBL_ADD_BUTTON'=> 'Add',
	'LBL_DEFAULT_SUBPANEL_TITLE' => 'Calls',
   'LBL_LOG_CALL'=> 'Log Call',
   'LNK_SELECT_ACCOUNT'=> 'Select Account',
   'LNK_NEW_ACCOUNT'=> 'New Account',
   'LNK_NEW_OPPORTUNITY'=> 'New Opportunity',
    'LBL_DEL' => 'Del',
    'LBL_LEADS_SUBPANEL_TITLE' => 'Leads',
    'LBL_CONTACTS_SUBPANEL_TITLE' => 'Contacts',
    'LBL_USERS_SUBPANEL_TITLE' => 'Users',
    'LBL_OUTLOOK_ID' => 'Outlook ID',
    'LBL_MEMBER_OF' => 'Member Of',
    'LBL_HISTORY_SUBPANEL_TITLE' => 'Notes',
   'LBL_LIST_ASSIGNED_TO_NAME' => 'Assigned to',
   'LBL_LIST_MY_CALLS' => 'My Calls',
   'LBL_SELECT_FROM_DROPDOWN' => 'Please make a selection from the Related To dropdown list first.',
	'LBL_ASSIGNED_TO_NAME' => 'Assigned to',
	'LBL_ASSIGNED_TO_ID' => 'Assigned User',
    'NOTICE_DURATION_TIME' => 'Duration time must be greater than 0',
    'LBL_CALL_INFORMATION' => 'Call Overview',
    'LBL_REMOVE' => 'rem',
);


?>
